@@ -10,8 +10,7 @@ from ground_soil.fabric import eval_kwargs
 from ground_soil.filesystem import temporary_directory, rsync
 from beanstalk import (IDENTIFIER as beanstalk_identifier, BEANSTALK_LOCAL_BASE_PATH,
                        __version__ as beanstalk_version_string, VERSION as beanstalk_version_tuple)
-from beanstalk.tasks.utils import (set_verbose_level, load_role_settings as load_beanstalk_settings,
-                                   load_web_servers, run_hooked_actions)
+from beanstalk.tasks.utils import set_verbose_level, load_role_settings, load_web_servers, run_hooked_actions
 from beanstalk.decorators import beanstalk_role
 from beanstalk.console.titles import section_title, tool_title, separator
 from beanstalk.validator import validate_web_server, validate_file_existence, validate_project_type, supported_projects
@@ -76,7 +75,7 @@ def plant(VERBOSE=0):
             beanstalk_default_settings[key] = value
 
     # Collect
-    beanstalk_default_settings = load_beanstalk_settings(default_only=True)
+    beanstalk_default_settings = load_role_settings(default_only=True)
     setting_set1 = [
         ('PROJECT_SOURCE_ROOT', 'Project Source Root?', None, 'str'),
         ('PROJECT_NAME', 'Project Name?', None, 'str'),
@@ -136,7 +135,7 @@ def plant(VERBOSE=0):
 
 @task
 @beanstalk_role('app')
-def deploy(**settings_patches):
+def deploy(settings_path=None, **settings_patches):
     """Deploy project in current work folder to beanstalk-stack
     """
     # Set variables
@@ -145,7 +144,7 @@ def deploy(**settings_patches):
 
     # Load beanstalk settings
     settings_patches = eval_kwargs(settings_patches)
-    beanstalk_settings = load_beanstalk_settings(**settings_patches)
+    beanstalk_settings = load_role_settings(additional_settings_path=settings_path, **settings_patches)
 
     # Get variables from settings
     project_name = beanstalk_settings['PROJECT_NAME']
